( cd boot ; rm -rf System.map )
( cd boot ; ln -sf System.map-2.4.29 System.map )
( cd boot ; rm -rf config )
( cd boot ; ln -sf config-2.4.29 config )
( cd boot ; rm -rf image )
( cd boot ; ln -sf image-2.4.29 image )
